changeset 8727:592bbf02e29d

(gobble_input): Block SIGALRM if we are using it.
author Richard M. Stallman <rms@gnu.org>
date Tue, 13 Sep 1994 04:13:32 +0000
parents fcf64871aa14
children b30c35c8e7ed
files src/keyboard.c
diffstat 1 files changed, 11 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/keyboard.c	Sun Sep 11 08:36:36 1994 +0000
+++ b/src/keyboard.c	Tue Sep 13 04:13:32 1994 +0000
@@ -3415,7 +3415,7 @@
   *addr = !NILP (Vquit_flag) || readable_events ();
 }
 
 /* Interface to read_avail_input, blocking SIGIO if necessary.  */
 
 int
 gobble_input (expected)
@@ -3432,6 +3432,16 @@
     }
   else
 #endif
+#ifdef POLL_FOR_INPUT
+  if (read_socket_hook && !interrupt_input && poll_suppress_count == 0)
+    {
+      SIGMASKTYPE mask;
+      mask = sigblockx (SIGALRM);
+      read_avail_input (expected);
+      sigsetmask (mask);
+    }
+  else
+#endif
     read_avail_input (expected);
 #endif
 }
@@ -3415,7 +3415,7 @@
 }
 
-/* Interface to read_avail_input, blocking SIGIO if necessary.  */
+/* Interface to read_avail_input, blocking SIGIO or SIGALRM if necessary.  */
 
 int